import{p as g,k as D,y as M,d as P,O as I,c as t,e as n,w as o,N as S,D as A,a5 as b,f as u,j as d,g as V,u as p,M as N,h as v,t as r,aC as O,W as C,ae as X,_ as Y,s as T}from"./index-Dh8vTPrL.js";import{V as _,M as L}from"./VCheckbox-BHLOyC9w.js";import{V as $}from"./VCard-DBrKNDRb.js";import{e as z,g as F,c as H}from"./VMenu-bkp9FdIZ.js";import{A as E,B as w,V as j,s as R}from"./VListItem-BiYBTZ39.js";import{_ as W}from"./_plugin-vue_export-helper-DlAUqK2U.js";const q=g({disabled:Boolean,modelValue:{type:Boolean,default:null},...z()},"VHover"),G=D()({name:"VHover",props:q(),emits:{"update:modelValue":l=>!0},setup(l,f){let{slots:a}=f;const s=M(l,"modelValue"),{runOpenDelay:m,runCloseDelay:y}=F(l,i=>!l.disabled&&(s.value=i));return()=>{var i;return(i=a.default)==null?void 0:i.call(a,{isHovering:s.value,props:{onMouseenter:m,onMouseleave:y}})}}}),J=["model-value"],K={key:0},Q={key:1},U={key:2},Z=P({__name:"PanelviewItemCompact",props:{item:{},size:{default:200},isSelected:{type:Boolean,default:!1},showCheckboxes:{type:Boolean,default:!1},permanentOverlay:{type:Boolean,default:!1},isAvailable:{type:Boolean,default:!0}},emits:["menu","click","play","select"],setup(l,{emit:f}){const a=l,s=f,m=function(e){if(a.showCheckboxes)return;const k="clientX"in e?e.clientX:e.touches[0].clientX,h="clientY"in e?e.clientY:e.touches[0].clientY;s("menu",a.item,k,h)},y=function(e){if(a.showCheckboxes){s("select",a.item,!a.isSelected);return}s("click",a.item,e.clientX,e.clientY)},i=function(e){a.showCheckboxes||s("play",a.item,e.clientX,e.clientY)};return(e,k)=>{const h=I("hold");return t(),n(G,null,{default:o(({isHovering:c,props:B})=>[S((t(),n($,A(B,{class:{"on-hover":c,unavailable:!e.isAvailable},elevation:c?3:0,onClick:y,onContextmenu:b(m,["right","prevent"])}),{default:o(()=>[e.showCheckboxes?(t(),n(H,{key:0,"model-value":e.showCheckboxes,contained:"",scrim:e.isSelected?e.$vuetify.theme.current.dark?"rgba(0,0,0,.75)":"rgba(255,255,255,.75)":"#ffffff00"},{default:o(()=>[u(_,{class:"panel-item-checkbox",ripple:!1,"model-value":e.isSelected},null,8,["model-value"])]),_:1},8,["model-value","scrim"])):d("",!0),u(L,{item:e.isAvailable?e.item:void 0},null,8,["item"]),V("div",{class:Y(e.$vuetify.theme.current.dark?"paneldetails-dark":"paneldetails"),"model-value":c||e.$vuetify.display.mobile||e.permanentOverlay},[u(j,{variant:"text",slim:"",tile:"",density:"compact",class:"panel-item-details"},{default:o(()=>[u(E,null,{default:o(()=>[e.item.media_type==p(N).FOLDER?(t(),v("span",K,[V("span",null,r(p(O)(e.item,e.$t)),1)])):(t(),v("span",Q,r(e.item.name),1)),"version"in e.item&&e.item.version?(t(),v("span",U," - "+r(e.item.version),1)):d("",!0)]),_:1}),"artists"in e.item&&e.item.artists?(t(),n(w,{key:0,class:"line-clamp-1"},{default:o(()=>[C(r(p(X)(e.item.artists,1)),1)]),_:1})):"owner"in e.item&&e.item.owner?(t(),n(w,{key:1,class:"line-clamp-1"},{default:o(()=>[C(r(e.item.owner),1)]),_:1})):d("",!0)]),_:1})],10,J),(c||p(T).isTouchscreen)&&e.isAvailable?(t(),n(R,{key:1,icon:"mdi-play",color:"primary",fab:"",size:"small",style:{position:"absolute",right:"10px",bottom:"35px",opacity:"0.8"},onClick:b(i,["stop"])})):d("",!0)]),_:2},1040,["class","elevation"])),[[h,m]])]),_:1})}}}),le=W(Z,[["__scopeId","data-v-c0cf806c"]]);export{le as P,G as V};
