import{d as s,a7 as m,x as n,V as e,c as l,h as c,f as u,b as f}from"./index-Dh8vTPrL.js";import{I as h}from"./ItemsListing-D0_QSUgh.js";import"./VCheckbox-BHLOyC9w.js";import"./eventbus-Bx0SmCX1.js";import"./VListItem-BiYBTZ39.js";import"./VCheckboxBtn-CNxrFD70.js";import"./VList-3zZGcDKM.js";import"./VCardText-BRzAu4nY.js";import"./VCard-DBrKNDRb.js";import"./VMenu-bkp9FdIZ.js";import"./_plugin-vue_export-helper-DlAUqK2U.js";import"./ListItem-BrzlQzsJ.js";import"./Button-uBTEHpd0.js";import"./VSpacer-ByaMfX_d.js";/* empty css              */import"./PanelviewItemCompact-Dp_kpJNm.js";import"./VAlert-6B6_WW_o.js";import"./Container-CJnP1AXv.js";import"./Toolbar-DtRA5hwR.js";import"./VToolbar-BUh6HJIk.js";import"./VTextField-Dm45LZPf.js";import"./VInfiniteScroll-BuVahgbA.js";import"./layout-Dlul22en.js";import"./VVirtualScroll-BqfdfU30.js";const K=s({__name:"BrowseView",props:{path:{}},setup(i){const t=i,{t:o}=m(),a=n(()=>!t.path||t.path=="root"?o("browse"):e("bp6")?o("browse")+" | "+t.path:e("bp3")?t.path:o("browse")),p=async function(r){return await f.browse(t.path)};return(r,w)=>(l(),c("section",null,[u(h,{itemtype:"browse","show-provider":!1,"show-library":!1,"show-favorites-only-filter":!1,"show-track-number":!1,"load-items":p,"sort-keys":["original","name","name_desc"],title:a.value,path:r.path,"allow-key-hooks":!0,icon:"mdi-folder-outline"},null,8,["title","path"])]))}});export{K as default};
